# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/fusion/hook/hook.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dbtlabs.proto.public.v1.events.fusion.phase import phase_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_events_dot_fusion_dot_phase_dot_phase__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5dbtlabs/proto/public/v1/events/fusion/hook/hook.proto\x12\x1cv1.public.events.fusion.hook\x1a\x37\x64\x62tlabs/proto/public/v1/events/fusion/phase/phase.proto\"\xbf\x02\n\rHookProcessed\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\x12\x11\n\x04name\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x39\n\thook_type\x18\x03 \x01(\x0e\x32&.v1.public.events.fusion.hook.HookType\x12\x12\n\nhook_index\x18\x04 \x01(\r\x12\x11\n\tunique_id\x18\x05 \x01(\t\x12?\n\x0chook_outcome\x18\x06 \x01(\x0e\x32).v1.public.events.fusion.hook.HookOutcome\x12\x1b\n\x13\x64\x62t_core_event_code\x18\x07 \x01(\t\x12<\n\x05phase\x18\x08 \x01(\x0e\x32-.v1.public.events.fusion.phase.ExecutionPhaseB\x07\n\x05_name*\x8c\x01\n\x08HookType\x12\x19\n\x15HOOK_TYPE_UNSPECIFIED\x10\x00\x12\x1a\n\x16HOOK_TYPE_ON_RUN_START\x10\x01\x12\x18\n\x14HOOK_TYPE_ON_RUN_END\x10\x02\x12\x16\n\x12HOOK_TYPE_PRE_HOOK\x10\x03\x12\x17\n\x13HOOK_TYPE_POST_HOOK\x10\x04*x\n\x0bHookOutcome\x12\x1c\n\x18HOOK_OUTCOME_UNSPECIFIED\x10\x00\x12\x18\n\x14HOOK_OUTCOME_SUCCESS\x10\x01\x12\x16\n\x12HOOK_OUTCOME_ERROR\x10\x02\x12\x19\n\x15HOOK_OUTCOME_CANCELED\x10\x03\x42?Z=github.com/dbt-labs/proto-golang/v1/public/events/fusion/hookb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.fusion.hook.hook_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z=github.com/dbt-labs/proto-golang/v1/public/events/fusion/hook'
  _globals['_HOOKTYPE']._serialized_start=467
  _globals['_HOOKTYPE']._serialized_end=607
  _globals['_HOOKOUTCOME']._serialized_start=609
  _globals['_HOOKOUTCOME']._serialized_end=729
  _globals['_HOOKPROCESSED']._serialized_start=145
  _globals['_HOOKPROCESSED']._serialized_end=464
# @@protoc_insertion_point(module_scope)
