"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _OnboardingScreen:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _OnboardingScreenEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_OnboardingScreen.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ONBOARDING_SCREEN_UNSPECIFIED: _OnboardingScreen.ValueType  # 0
    ONBOARDING_SCREEN_WELCOME: _OnboardingScreen.ValueType  # 1
    ONBOARDING_SCREEN_PROFILE_CHECK: _OnboardingScreen.ValueType  # 2
    ONBOARDING_SCREEN_PROFILE_FOUND: _OnboardingScreen.ValueType  # 3
    ONBOARDING_SCREEN_PROFILE_SETUP: _OnboardingScreen.ValueType  # 4
    ONBOARDING_SCREEN_LINK_ACCOUNT: _OnboardingScreen.ValueType  # 5
    ONBOARDING_SCREEN_DBT_PARSE: _OnboardingScreen.ValueType  # 6
    ONBOARDING_SCREEN_PARSE_ERROR_AUTOFIX: _OnboardingScreen.ValueType  # 7
    ONBOARDING_SCREEN_DBT_PARSE_RETRY: _OnboardingScreen.ValueType  # 8
    ONBOARDING_SCREEN_PARSE_ERROR_FAIL: _OnboardingScreen.ValueType  # 9
    ONBOARDING_SCREEN_COMPILE_NO_SA: _OnboardingScreen.ValueType  # 10
    ONBOARDING_SCREEN_COMPILE_NO_SA_FAIL: _OnboardingScreen.ValueType  # 11
    ONBOARDING_SCREEN_COMPILE: _OnboardingScreen.ValueType  # 12
    ONBOARDING_SCREEN_COMPILE_FAIL: _OnboardingScreen.ValueType  # 13
    ONBOARDING_SCREEN_SUCCESS: _OnboardingScreen.ValueType  # 14
    ONBOARDING_SCREEN_AGENTIC_AUTOFIX: _OnboardingScreen.ValueType  # 15
    ONBOARDING_SCREEN_TRY_AGENTIC_AUTOFIX: _OnboardingScreen.ValueType  # 16
    ONBOARDING_SCREEN_DOWNLOAD_AGENTS_MD: _OnboardingScreen.ValueType  # 17
    ONBOARDING_SCREEN_COMPILE_SA_BASELINE: _OnboardingScreen.ValueType  # 18
    ONBOARDING_SCREEN_COMPILE_SA_BASELINE_SUCCESS: _OnboardingScreen.ValueType  # 19

class OnboardingScreen(_OnboardingScreen, metaclass=_OnboardingScreenEnumTypeWrapper): ...

ONBOARDING_SCREEN_UNSPECIFIED: OnboardingScreen.ValueType  # 0
ONBOARDING_SCREEN_WELCOME: OnboardingScreen.ValueType  # 1
ONBOARDING_SCREEN_PROFILE_CHECK: OnboardingScreen.ValueType  # 2
ONBOARDING_SCREEN_PROFILE_FOUND: OnboardingScreen.ValueType  # 3
ONBOARDING_SCREEN_PROFILE_SETUP: OnboardingScreen.ValueType  # 4
ONBOARDING_SCREEN_LINK_ACCOUNT: OnboardingScreen.ValueType  # 5
ONBOARDING_SCREEN_DBT_PARSE: OnboardingScreen.ValueType  # 6
ONBOARDING_SCREEN_PARSE_ERROR_AUTOFIX: OnboardingScreen.ValueType  # 7
ONBOARDING_SCREEN_DBT_PARSE_RETRY: OnboardingScreen.ValueType  # 8
ONBOARDING_SCREEN_PARSE_ERROR_FAIL: OnboardingScreen.ValueType  # 9
ONBOARDING_SCREEN_COMPILE_NO_SA: OnboardingScreen.ValueType  # 10
ONBOARDING_SCREEN_COMPILE_NO_SA_FAIL: OnboardingScreen.ValueType  # 11
ONBOARDING_SCREEN_COMPILE: OnboardingScreen.ValueType  # 12
ONBOARDING_SCREEN_COMPILE_FAIL: OnboardingScreen.ValueType  # 13
ONBOARDING_SCREEN_SUCCESS: OnboardingScreen.ValueType  # 14
ONBOARDING_SCREEN_AGENTIC_AUTOFIX: OnboardingScreen.ValueType  # 15
ONBOARDING_SCREEN_TRY_AGENTIC_AUTOFIX: OnboardingScreen.ValueType  # 16
ONBOARDING_SCREEN_DOWNLOAD_AGENTS_MD: OnboardingScreen.ValueType  # 17
ONBOARDING_SCREEN_COMPILE_SA_BASELINE: OnboardingScreen.ValueType  # 18
ONBOARDING_SCREEN_COMPILE_SA_BASELINE_SUCCESS: OnboardingScreen.ValueType  # 19
Global___OnboardingScreen: typing_extensions.TypeAlias = OnboardingScreen

@typing.final
class OnboardingScreenShown(google.protobuf.message.Message):
    """Onboarding step event."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCREEN_FIELD_NUMBER: builtins.int
    screen: Global___OnboardingScreen.ValueType
    """Onboarding screen identifier"""
    def __init__(
        self,
        *,
        screen: Global___OnboardingScreen.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["screen", b"screen"]) -> None: ...

Global___OnboardingScreenShown: typing_extensions.TypeAlias = OnboardingScreenShown
