# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/fusion/onboarding/onboarding.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAdbtlabs/proto/public/v1/events/fusion/onboarding/onboarding.proto\x12\"v1.public.events.fusion.onboarding\"]\n\x15OnboardingScreenShown\x12\x44\n\x06screen\x18\x01 \x01(\x0e\x32\x34.v1.public.events.fusion.onboarding.OnboardingScreen*\x8d\x06\n\x10OnboardingScreen\x12!\n\x1dONBOARDING_SCREEN_UNSPECIFIED\x10\x00\x12\x1d\n\x19ONBOARDING_SCREEN_WELCOME\x10\x01\x12#\n\x1fONBOARDING_SCREEN_PROFILE_CHECK\x10\x02\x12#\n\x1fONBOARDING_SCREEN_PROFILE_FOUND\x10\x03\x12#\n\x1fONBOARDING_SCREEN_PROFILE_SETUP\x10\x04\x12\"\n\x1eONBOARDING_SCREEN_LINK_ACCOUNT\x10\x05\x12\x1f\n\x1bONBOARDING_SCREEN_DBT_PARSE\x10\x06\x12)\n%ONBOARDING_SCREEN_PARSE_ERROR_AUTOFIX\x10\x07\x12%\n!ONBOARDING_SCREEN_DBT_PARSE_RETRY\x10\x08\x12&\n\"ONBOARDING_SCREEN_PARSE_ERROR_FAIL\x10\t\x12#\n\x1fONBOARDING_SCREEN_COMPILE_NO_SA\x10\n\x12(\n$ONBOARDING_SCREEN_COMPILE_NO_SA_FAIL\x10\x0b\x12\x1d\n\x19ONBOARDING_SCREEN_COMPILE\x10\x0c\x12\"\n\x1eONBOARDING_SCREEN_COMPILE_FAIL\x10\r\x12\x1d\n\x19ONBOARDING_SCREEN_SUCCESS\x10\x0e\x12%\n!ONBOARDING_SCREEN_AGENTIC_AUTOFIX\x10\x0f\x12)\n%ONBOARDING_SCREEN_TRY_AGENTIC_AUTOFIX\x10\x10\x12(\n$ONBOARDING_SCREEN_DOWNLOAD_AGENTS_MD\x10\x11\x12)\n%ONBOARDING_SCREEN_COMPILE_SA_BASELINE\x10\x12\x12\x31\n-ONBOARDING_SCREEN_COMPILE_SA_BASELINE_SUCCESS\x10\x13\x42\x45ZCgithub.com/dbt-labs/proto-golang/v1/public/events/fusion/onboardingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.fusion.onboarding.onboarding_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZCgithub.com/dbt-labs/proto-golang/v1/public/events/fusion/onboarding'
  _globals['_ONBOARDINGSCREEN']._serialized_start=201
  _globals['_ONBOARDINGSCREEN']._serialized_end=982
  _globals['_ONBOARDINGSCREENSHOWN']._serialized_start=105
  _globals['_ONBOARDINGSCREENSHOWN']._serialized_end=198
# @@protoc_insertion_point(module_scope)
