# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/fusion/log/show_result.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;dbtlabs/proto/public/v1/events/fusion/log/show_result.proto\x12\x1bv1.public.events.fusion.log\"\xb3\x01\n\nShowResult\x12J\n\routput_format\x18\x01 \x01(\x0e\x32\x33.v1.public.events.fusion.log.ShowResultOutputFormat\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\x13\n\x0bresult_type\x18\x03 \x01(\t\x12\r\n\x05title\x18\x04 \x01(\t\x12\x16\n\tunique_id\x18\x05 \x01(\tH\x00\x88\x01\x01\x42\x0c\n\n_unique_id*g\n\x16ShowResultOutputFormat\x12)\n%SHOW_RESULT_OUTPUT_FORMAT_UNSPECIFIED\x10\x00\x12\"\n\x1eSHOW_RESULT_OUTPUT_FORMAT_TEXT\x10\x01\x42>Z<github.com/dbt-labs/proto-golang/v1/public/events/fusion/logb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.fusion.log.show_result_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z<github.com/dbt-labs/proto-golang/v1/public/events/fusion/log'
  _globals['_SHOWRESULTOUTPUTFORMAT']._serialized_start=274
  _globals['_SHOWRESULTOUTPUTFORMAT']._serialized_end=377
  _globals['_SHOWRESULT']._serialized_start=93
  _globals['_SHOWRESULT']._serialized_end=272
# @@protoc_insertion_point(module_scope)
