# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/fusion/generic/generic.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;dbtlabs/proto/public/v1/events/fusion/generic/generic.proto\x12\x1fv1.public.events.fusion.generic\"u\n\x11GenericOpExecuted\x12\x14\n\x0coperation_id\x18\x01 \x01(\t\x12\x16\n\x0e\x64isplay_action\x18\x02 \x01(\t\x12\x1d\n\x10item_count_total\x18\x03 \x01(\x04H\x00\x88\x01\x01\x42\x13\n\x11_item_count_total\"\x85\x01\n\x16GenericOpItemProcessed\x12\x14\n\x0coperation_id\x18\x01 \x01(\t\x12\"\n\x1a\x64isplay_in_progress_action\x18\x02 \x01(\t\x12!\n\x19\x64isplay_on_success_action\x18\x03 \x01(\t\x12\x0e\n\x06target\x18\x04 \x01(\tBBZ@github.com/dbt-labs/proto-golang/v1/public/events/fusion/genericb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.fusion.generic.generic_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z@github.com/dbt-labs/proto-golang/v1/public/events/fusion/generic'
  _globals['_GENERICOPEXECUTED']._serialized_start=96
  _globals['_GENERICOPEXECUTED']._serialized_end=213
  _globals['_GENERICOPITEMPROCESSED']._serialized_start=216
  _globals['_GENERICOPITEMPROCESSED']._serialized_end=349
# @@protoc_insertion_point(module_scope)
