# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/fusion/asset/asset.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dbtlabs.proto.public.v1.events.fusion.phase import phase_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_events_dot_fusion_dot_phase_dot_phase__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7dbtlabs/proto/public/v1/events/fusion/asset/asset.proto\x12\x1dv1.public.events.fusion.asset\x1a\x37\x64\x62tlabs/proto/public/v1/events/fusion/phase/phase.proto\"\xc2\x01\n\x0b\x41ssetParsed\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x15\n\rrelative_path\x18\x03 \x01(\t\x12\x14\n\x0c\x64isplay_path\x18\x04 \x01(\t\x12\x16\n\tunique_id\x18\x05 \x01(\tH\x00\x88\x01\x01\x12<\n\x05phase\x18\x06 \x01(\x0e\x32-.v1.public.events.fusion.phase.ExecutionPhaseB\x0c\n\n_unique_idB@Z>github.com/dbt-labs/proto-golang/v1/public/events/fusion/assetb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.fusion.asset.asset_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z>github.com/dbt-labs/proto-golang/v1/public/events/fusion/asset'
  _globals['_ASSETPARSED']._serialized_start=148
  _globals['_ASSETPARSED']._serialized_end=342
# @@protoc_insertion_point(module_scope)
