# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/fusion/process/process.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;dbtlabs/proto/public/v1/events/fusion/process/process.proto\x12\x1fv1.public.events.fusion.process\"O\n\x07Process\x12\x0f\n\x07package\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\t\x12\x0f\n\x07host_os\x18\x05 \x01(\t\x12\x11\n\thost_arch\x18\x06 \x01(\tBBZ@github.com/dbt-labs/proto-golang/v1/public/events/fusion/processb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.fusion.process.process_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z@github.com/dbt-labs/proto-golang/v1/public/events/fusion/process'
  _globals['_PROCESS']._serialized_start=96
  _globals['_PROCESS']._serialized_end=175
# @@protoc_insertion_point(module_scope)
